==> haskell-language-python-0.5.4-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.4
id: language-python-0.5.4-GTdecB6vB6k1srtcsZ8lr4
key: language-python-0.5.4-GTdecB6vB6k1srtcsZ8lr4
license: BSD3
copyright: (c) 2008-2016 Bernard James Pope
maintainer: florbitous@gmail.com
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
author: Bernard James Pope (Bernie Pope)
exposed: True
exposed-modules:
    Language.Python.Common Language.Python.Common.ParseError
    Language.Python.Common.SrcLocation Language.Python.Common.Pretty
    Language.Python.Common.Token Language.Python.Common.ParserMonad
    Language.Python.Common.PrettyToken Language.Python.Common.AST
    Language.Python.Common.PrettyAST Language.Python.Version3
    Language.Python.Version3.Parser Language.Python.Version3.Lexer
    Language.Python.Version2 Language.Python.Version2.Parser
    Language.Python.Version2.Lexer
    Language.Python.Common.PrettyParseError
    Language.Python.Common.StringEscape
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
abi: 0daa5841253465799e34a2f80f295c71
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/language-python-0.5.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/language-python-0.5.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/language-python-0.5.4
hs-libraries: HSlanguage-python-0.5.4-GTdecB6vB6k1srtcsZ8lr4
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
    monads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn pretty-1.1.3.3
    transformers-0.5.2.0 utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-python-0.5.4-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.4
id: language-python-0.5.4-JXKJGAeelZMCJUtCZc4use
key: language-python-0.5.4-JXKJGAeelZMCJUtCZc4use
license: BSD3
copyright: (c) 2008-2016 Bernard James Pope
maintainer: florbitous@gmail.com
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
author: Bernard James Pope (Bernie Pope)
exposed: True
exposed-modules:
    Language.Python.Common Language.Python.Common.ParseError
    Language.Python.Common.SrcLocation Language.Python.Common.Pretty
    Language.Python.Common.Token Language.Python.Common.ParserMonad
    Language.Python.Common.PrettyToken Language.Python.Common.AST
    Language.Python.Common.PrettyAST Language.Python.Version3
    Language.Python.Version3.Parser Language.Python.Version3.Lexer
    Language.Python.Version2 Language.Python.Version2.Parser
    Language.Python.Version2.Lexer
    Language.Python.Common.PrettyParseError
    Language.Python.Common.StringEscape
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
abi: a622ba47b9328e79df422eafdff1821e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/language-python-0.5.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/language-python-0.5.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/language-python-0.5.4
hs-libraries: HSlanguage-python-0.5.4-JXKJGAeelZMCJUtCZc4use
depends:
    array-0.5.1.1 base-4.9.1.0 containers-0.5.7.1
    monads-tf-0.1.0.3-JIPNoZ6aJW379YQZJvMYoR pretty-1.1.3.3
    transformers-0.5.2.0 utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
